package com.ruoyi.project.reliability.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.reliability.mapper.TDeviceRiskMapper;
import com.ruoyi.project.reliability.domain.TDeviceRisk;
import com.ruoyi.project.reliability.service.ITDeviceRiskService;

/**
 * 装置风险清单Service业务层处理
 *
 * @author ruoyi
 * @date 2022-07-07
 */
@Service
public class TDeviceRiskServiceImpl implements ITDeviceRiskService
{
    @Autowired
    private TDeviceRiskMapper tDeviceRiskMapper;

    /**
     * 查询装置风险清单
     *
     * @param id 装置风险清单ID
     * @return 装置风险清单
     */
    @Override
    public TDeviceRisk selectTDeviceRiskById(Long id)
    {
        return tDeviceRiskMapper.selectTDeviceRiskById(id);
    }

    /**
     * 查询装置风险清单列表
     *
     * @param tDeviceRisk 装置风险清单
     * @return 装置风险清单
     */
    @Override
    public List<TDeviceRisk> selectTDeviceRiskList(TDeviceRisk tDeviceRisk)
    {
        return tDeviceRiskMapper.selectTDeviceRiskList(tDeviceRisk);
    }

    /**
     * 新增装置风险清单
     *
     * @param tDeviceRisk 装置风险清单
     * @return 结果
     */
    @Override
    public int insertTDeviceRisk(TDeviceRisk tDeviceRisk)
    {
        return tDeviceRiskMapper.insertTDeviceRisk(tDeviceRisk);
    }

    /**
     * 修改装置风险清单
     *
     * @param tDeviceRisk 装置风险清单
     * @return 结果
     */
    @Override
    public int updateTDeviceRisk(TDeviceRisk tDeviceRisk)
    {
        return tDeviceRiskMapper.updateTDeviceRisk(tDeviceRisk);
    }

    /**
     * 批量删除装置风险清单
     *
     * @param ids 需要删除的装置风险清单ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceRiskByIds(Long[] ids)
    {
        return tDeviceRiskMapper.deleteTDeviceRiskByIds(ids);
    }

    /**
     * 删除装置风险清单信息
     *
     * @param id 装置风险清单ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceRiskById(Long id)
    {
        return tDeviceRiskMapper.deleteTDeviceRiskById(id);
    }
}
